@@ -25,8 +25,7 @@ class Invoice(object):
                 vat_item = VatItem(rate=item.vat_rate)
                 d[item.vat_rate] = vat_item
             vat_item.amount += item.vat_rate * item.subtotal
-        self.vat_items = d.values()
-        self.vat_items.sort(key=lambda item: item.rate)
+        self.vat_items = sorted(d.values(), key=lambda item: item.rate)
 
     @property
     def gross(self):
