@@ -14,6 +14,13 @@ styles.add(ParagraphStyle(
     leading=12
 ))
 
+styles.add(ParagraphStyle(
+    name='InfoboxH1',
+    parent=styles['Normal'],
+    fontSize=16,
+    leading=8,
+    spaceAfter=10*mm))
+
 styles.add(ParagraphStyle(
     name='InfoboxTitle',
     parent=styles['Normal'],
@@ -109,6 +116,7 @@ styles.add(ParagraphStyle(
 
 styles.add(ParagraphStyle(
     name='TableHead',
+    fontName='Helvetica-Bold',
     parent=styles['TableCell']))
 
 styles.add(ParagraphStyle(
